Alfred3 [![DOI](https://zenodo.org/badge/150700371.svg)](https://zenodo.org/badge/latestdoi/150700371)
======

Alfred3 - A library for rapid experiment development

Alfred3 is a package for Python 3 offering experimenters a fast and easy way to create truly dynamic computer experiments for a wide range of applications. See http://www.the-experimenter.com/framework for more information.

If you are publishing research conducted using Alfred3, please cite:

> Treffenstaedt, C., Wiemann, P. & Brachem, J. (2020). Alfred3 - A library for rapid experiment development (Version 1.1.0). Göttingen, Germany: [https://doi.org/10.5281/zenodo.1437219](https://doi.org/10.5281/zenodo.1437219)


# Installation

If you have Python 3 installed, you can install alfred3 via pip with the follwoing command. It is best practice to install alfred3 in a new virtual environment for every project (see [virtualenv package](https://virtualenv.pypa.io/en/latest/)).

```bash
pip install alfred3
```

A detailed **step-by-step video tutorial on setting up Alfred3** can be found here (created using MacOS, but applicable to Windows aswell): https://www.youtube.com/watch?v=6YbAN0q3p-E (German)

# Alfred3 Mailing List

If you want to stay up to date with current developments, you can [join our mailing list](https://listserv.gwdg.de/mailman/listinfo/Alfred).
We use this list to announce new releases and spread important information concerning the use of Alfred. You can expect to receive at most one mail per month.

